
Pretrained model ckpts. https://huggingface.co/SWivid/F5-TTS

```
ckpts/
    F5TTS_v1_Base/
        model_1250000.safetensors
    F5TTS_Base/
        model_1200000.safetensors
    E2TTS_Base/
        model_1200000.safetensors
```